abacusai.sftp_key — AbacusAI documentation

# abacusai.sftp_key

## Classes

`SftpKey` | An SFTP key

## Module Contents

class abacusai.sftp_key.SftpKey(client, keyName=None, publicKey=None)

  Bases: `abacusai.return_class.AbstractApiClass`

  An SFTP key

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - keyName (str) – The name of the key

    - publicKey (str) – The public key

  key_name = None
  public_key = None
  deprecated_keys
  __repr__()
  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict